16.156. cdist-type__timezone(7) — cdist 6.9.8 documentation

# 16.156. cdist-type__timezone(7)

## 16.156.1. NAME

cdist-type__timezone - Allows one to configure the desired localtime timezone.

## 16.156.2. DESCRIPTION

This type creates a symlink (/etc/localtime) to the selected timezone (which should be available in /usr/share/zoneinfo).

## 16.156.3. REQUIRED PARAMETERS

tz

  The name of timezone to set.

## 16.156.4. OPTIONAL PARAMETERS

None.

## 16.156.5. EXAMPLES

    # Set up Europe/Andorra as our timezone.
    __timezone --tz Europe/Andorra

    # Set up US/Central as our timezone.
    __timezone --tz US/Central

## 16.156.6. AUTHORS

Steven Armstrong <steven-cdist--@--armstrong.cc>
Nico Schottelius <nico-cdist--@--schottelius.org>
Ramon Salvadó <rsalvado--@--gnuine--dot--com>
Dennis Camera <dennis.camera--@--ssrq-sds-fds.ch>

## 16.156.7. COPYING

Copyright (C) 2012-2020 the AUTHORS. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.